@@ -11,6 +11,7 @@
 # distributed under the License is distributed on an "AS IS" BASIS. See the
 # License for the specific language.
 
-from .base import BaseAuthHandler
+from .base import BaseAuth
 from .cli import CliAuth
+from .password import PasswordAuth
 from .service_account import ServiceAccountAuth
