@@ -11,7 +11,6 @@
 # distributed under the License is distributed on an "AS IS" BASIS. See the
 # License for the specific language.
 
-import os
 from functools import wraps
 from typing import (
     Any,
@@ -47,7 +46,14 @@ def global_value(key: str) -> Callable:
     return decorator
 
 
-@global_value("CLI_AUTH")
-def get_cli_auth() -> CliAuth:
-    """Returns global `CliAuth` object."""
-    return CliAuth(os.getenv("QCTRL_OIDC_URL", DEFAULT_OIDC_URL))
+def invalidate_global_value(*keys: str):
+    """Removes the globally registered values, if they exist."""
+    for key in keys:
+        if key in _REGISTRY:
+            del _REGISTRY[key]
+
+
+@global_value("DEFAULT_CLI_AUTH")
+def get_default_cli_auth() -> CliAuth:
+    """Returns default `CliAuth` object."""
+    return CliAuth(DEFAULT_OIDC_URL)
